from setuptools import setup, find_packages

setup(
    name="zfb3_1",
    version="1.0.6",
    packages=find_packages(),
    description="""print(函数)
    ZifuYinter 字符映射表 ZifuYinter(1-26) 对应 a-z 加 d大写
ShiZer 10-2 ShiZer(x)
ShiZba 10-8 ShiZba(x)
ShiZsl 10-16 ShiZsl(x)
Vision 作者信息 Vision()
ertsfer 10-2>36 ertsfer("x", 2-36, 2-36)
ab 计算 ab("x")
X_x 对比 X_x("x", "x")
text_text 翻转 text_txet("x") 加 True单词反转
Abcer 1-9 排序 Abcer(x) 加 zm变字母
Genhaer 根号 Genhaer(x)
Jxjer 加解密 Jxjer("Jia(x)") 加密 Jxjer("jie(x)")
Haxizer 哈希值 Haxizer("x")
xxx 计算平均值 xxx([x, x, x])
Ymt 计算圆面积与体积 Ymt(xx, 'xx')mj tj
Jzlmser 加密解密 Jzlmser("xx", 'x')Jm jm""",
    author="Gtl",
    author_email="vvvmcvvv@163.com",
)